@@ -1,8 +1,9 @@
 import re
 from pathlib import Path
+from typing import ClassVar, Dict, List
 
 from pygments.lexer import Lexer
-from pygments.token import Token
+from pygments.token import Token, _TokenType
 from robot.parsing import get_tokens
 
 
@@ -46,19 +47,18 @@ def get_variable_token(token_list):
         if len(token.value) == 0:
             continue
         try:
-            var_tokens = token.tokenize_variables()
+            var_tokens = list(token.tokenize_variables())
         except Exception:
             var_tokens = [token]
-        for v_token in var_tokens:
-            yield v_token
+        yield from var_tokens
 
 
 class RobotFrameworkLocalLexer(Lexer):
     name = "RobotFramework"
     url = "http://robotframework.org"
-    aliases = ["robotframework"]
-    filenames = ["*.robot", "*.resource"]
-    mimetypes = ["text/x-robotframework"]
+    aliases: ClassVar[List[str]] = ["robotframework"]
+    filenames: ClassVar[List[str]] = ["*.robot", "*.resource"]
+    mimetypes: ClassVar[List[str]] = ["text/x-robotframework"]
 
     # PYGMENTS_STANDARD_TYPES = {
     #     Token: '',
@@ -152,7 +152,7 @@ class RobotFrameworkLocalLexer(Lexer):
     #     Generic.Traceback: 'gt',
     # }
 
-    ROBOT_TO_PYGMENTS = {
+    ROBOT_TO_PYGMENTS: ClassVar[Dict[str, _TokenType]] = {
         "HEADER": Token.Keyword.Namespace,
         "DEFINITION": Token.Name.Class,
         "SETTING HEADER": Token.Keyword.Namespace,
@@ -206,6 +206,7 @@ class RobotFrameworkLocalLexer(Lexer):
         "CONTINUE": Token.Keyword,
         "BREAK": Token.Keyword,
         "OPTION": Token.Keyword,
+        "VAR": Token.Keyword,
         "SEPARATOR": Token.Punctuation,
         "COMMENT": Token.Comment,
         "CONTINUATION": Token.Operator,
